==> zio-aws-ecs_2.13-5.17.157.2-sources.jar: zio/aws/ecs/model/UpdateContainerAgentResponse.scala <==
package zio.aws.ecs.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class UpdateContainerAgentResponse(
    containerInstance: Option[zio.aws.ecs.model.ContainerInstance] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ecs.model.UpdateContainerAgentResponse = {
    import UpdateContainerAgentResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ecs.model.UpdateContainerAgentResponse
      .builder()
      .optionallyWith(containerInstance.map(value => value.buildAwsValue()))(
        _.containerInstance
      )
      .build()
  }
  def asReadOnly: zio.aws.ecs.model.UpdateContainerAgentResponse.ReadOnly =
    zio.aws.ecs.model.UpdateContainerAgentResponse.wrap(buildAwsValue())
}
object UpdateContainerAgentResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ecs.model.UpdateContainerAgentResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ecs.model.UpdateContainerAgentResponse =
      zio.aws.ecs.model.UpdateContainerAgentResponse(
        containerInstance.map(value => value.asEditable)
      )
    def containerInstance: Option[zio.aws.ecs.model.ContainerInstance.ReadOnly]
    def getContainerInstance
        : ZIO[Any, AwsError, zio.aws.ecs.model.ContainerInstance.ReadOnly] =
      AwsError.unwrapOptionField("containerInstance", containerInstance)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ecs.model.UpdateContainerAgentResponse
  ) extends zio.aws.ecs.model.UpdateContainerAgentResponse.ReadOnly {
    override val containerInstance
        : Option[zio.aws.ecs.model.ContainerInstance.ReadOnly] = scala
      .Option(impl.containerInstance())
      .map(value => zio.aws.ecs.model.ContainerInstance.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.ecs.model.UpdateContainerAgentResponse
  ): zio.aws.ecs.model.UpdateContainerAgentResponse.ReadOnly = new Wrapper(impl)
}

==> zio-aws-ecs_2.13-5.17.167.1-sources.jar: zio/aws/ecs/model/UpdateContainerAgentResponse.scala <==
package zio.aws.ecs.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class UpdateContainerAgentResponse(
    containerInstance: Optional[zio.aws.ecs.model.ContainerInstance] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ecs.model.UpdateContainerAgentResponse = {
    import UpdateContainerAgentResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ecs.model.UpdateContainerAgentResponse
      .builder()
      .optionallyWith(containerInstance.map(value => value.buildAwsValue()))(
        _.containerInstance
      )
      .build()
  }
  def asReadOnly: zio.aws.ecs.model.UpdateContainerAgentResponse.ReadOnly =
    zio.aws.ecs.model.UpdateContainerAgentResponse.wrap(buildAwsValue())
}
object UpdateContainerAgentResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ecs.model.UpdateContainerAgentResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ecs.model.UpdateContainerAgentResponse =
      zio.aws.ecs.model.UpdateContainerAgentResponse(
        containerInstance.map(value => value.asEditable)
      )
    def containerInstance
        : Optional[zio.aws.ecs.model.ContainerInstance.ReadOnly]
    def getContainerInstance
        : ZIO[Any, AwsError, zio.aws.ecs.model.ContainerInstance.ReadOnly] =
      AwsError.unwrapOptionField("containerInstance", containerInstance)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ecs.model.UpdateContainerAgentResponse
  ) extends zio.aws.ecs.model.UpdateContainerAgentResponse.ReadOnly {
    override val containerInstance
        : Optional[zio.aws.ecs.model.ContainerInstance.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.containerInstance())
        .map(value => zio.aws.ecs.model.ContainerInstance.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.ecs.model.UpdateContainerAgentResponse
  ): zio.aws.ecs.model.UpdateContainerAgentResponse.ReadOnly = new Wrapper(impl)
}
